def password():
    x = "BIcode"
    while x != "BIcode":
        x = input('password : ')
        if x == "BIcode":
            print('ok')
        else:
            print("Wrong Password")

